

/************************************************************************/
/*									*/
/*	oled_main.c -- Digilent board OLED Display Library Demo Program	*/
/*									*/
/************************************************************************/
/*	Author: 	Gene Apperson					*/
/*	Copyright 2011, Digilent Inc.					*/
/************************************************************************/
/*  Module Description: 						*/
/*	This provides an example of how to use the SPI-driven OLED
 * display on the ChipKit I/O board.  This code is based on code written
 * by Gene Apperson of Digilent Inc.  Part of it is from the MPIDE-
 * compatible example code and part from the MPLAB X example for the
 * stand-alone digilent OLED board.					*/
/*									*/
/************************************************************************/
/*  Revision History:                                   		*/
/*									*/
/*	07/06/2011(GeneA): created					*/
/*	October 2013: modified by James Andrew Smith			*/
/************************************************************************/


/* ------------------------------------------------------------ */
/*				Include File Definitions	*/
/* ------------------------------------------------------------ */

#include <p32xxxx.h>
#include <plib.h>
#include "OledDriver.h"
#include <inttypes.h>
#include "delay.h"

/* ------------------------------------------------------------ */
/*				PIC32 Configuration Settings		*/
/* ------------------------------------------------------------ */

/* Oscillator Settings
*/
#pragma config FNOSC		= PRIPLL	// Oscillator selection
#pragma config POSCMOD		= XT		// Primary oscillator mode
#pragma config FPLLIDIV 	= DIV_2		// PLL input divider
#pragma config FPLLMUL		= MUL_20	// PLL multiplier
#pragma config FPLLODIV 	= DIV_1		// PLL output divider
#pragma config FPBDIV		= DIV_1		// Peripheral bus clock divider
#pragma config FSOSCEN		= OFF		// Secondary oscillator enable

/* Clock control settings
*/
#pragma config IESO		= OFF		// Internal/external clock switchover
#pragma config FCKSM		= CSDCMD	// Clock switching (CSx)/Clock monitor (CMx)
#pragma config OSCIOFNC		= OFF		// Clock output on OSCO pin enable

/* USB Settings
*/
//#pragma config UPLLEN		= OFF		// USB PLL enable
//#pragma config UPLLIDIV	= DIV_2		// USB PLL input divider

/* Other Peripheral Device settings
*/
#pragma config FWDTEN		= OFF		// Watchdog timer enable
#pragma config WDTPS		= PS1024	// Watchdog timer postscaler

/* Code Protection settings
*/
#pragma config CP		= OFF		// Code protection
#pragma config BWP		= OFF		// Boot flash write protect
#pragma config PWP		= OFF		// Program flash write protect

/* Debug settings
*/
//#pragma config ICESEL		= ICS_PGx1	// ICE pin selection
//#pragma config DEBUG		= ON		// Debug mode select

/* ------------------------------------------------------------ */
/*				Local Type Definitions							*/
/* ------------------------------------------------------------ */

#define	fTrue	1
#define fFalse	0

#define cbPageMax	256

#define _BOARD_UC32_ 1      // this is the board we use.
#define	cntMsDelay	10000			//timer 1 delay for 1ms

/* ------------------------------------------------------------ */
/*				Global Variables								*/
/* ------------------------------------------------------------ */

extern BYTE	rgbOledBmp[];

BYTE rgbBmp0[] = {
	0x81, 0x42, 0x24, 0x18, 0x18, 0x24, 0x42, 0x81,
	0x18, 0x24, 0x42, 0x81, 0x81, 0x42, 0x24, 0x18
};

int testgraph[] = {
	1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
	1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
	1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
	1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
	1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
	1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
	1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
	1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
	1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
	1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
	1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
	1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
	1, 2, 3, 4, 5, 6, 7, 8
};

BYTE rgbBmp1[32];

BYTE rgbUserFont[cbOledFontUser] = {
	0x7E, 0x42, 0x42, 0x42, 0x42, 0x42, 0x42, 0x7E,	// 0x00
	0x81, 0x42, 0x24, 0x18, 0x18, 0x24, 0x42, 0x81,	// 0x01
	0x7E, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40,	// 0x02
	0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x7E,	// 0x03
	0x7E, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02,	// 0x04
	0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x7E,	// 0x05
	0x7E, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, 0x7E,	// 0x06
	0xAA, 0x55, 0xAA, 0x55, 0xAA, 0x55, 0xAA, 0x55, // 0x07
	0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80,	// 0x08
	0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40,	// 0x09
	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, // 0x0A
	0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, // 0x0B
	0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, // 0x0C
	0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, // 0x0D
	0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02,	// 0x0E
	0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,	// 0x0F
	0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,	// 0x10
	0x00, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,	// 0x11
	0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, // 0x12
	0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0x00, // 0x13
	0x00, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, // 0x14
	0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, // 0x15
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0x00,	// 0x16
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF	// 0x17
};

const BYTE rgbOledFont0[] = {
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,		// 0x20, space
	0x00,0x00,0x00,0x5f,0x00,0x00,0x00,0x00,		// 0x21, !
	0x00,0x00,0x03,0x00,0x03,0x00,0x00,0x00,		// 0x22, "
	0x64,0x3c,0x26,0x64,0x3c,0x26,0x24,0x00,		// 0x23, #
	0x26,0x49,0x49,0x7f,0x49,0x49,0x32,0x00,		// 0x23, $
	0x42,0x25,0x12,0x08,0x24,0x52,0x21,0x00,		// 0x25, %
	0x20,0x50,0x4e,0x55,0x22,0x58,0x28,0x00,		// 0x26, &
	0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,		// 0x27, '
	0x00,0x00,0x1c,0x22,0x41,0x00,0x00,0x00,		// 0x28, (
	0x00,0x00,0x00,0x41,0x22,0x1c,0x00,0x00,		// 0x29, )
	0x00,0x15,0x15,0x0e,0x0e,0x15,0x15,0x00,		// 0x2A, *
	0x00,0x08,0x08,0x3e,0x08,0x08,0x00,0x00,		// 0x2B, +
	0x00,0x00,0x00,0x50,0x30,0x00,0x00,0x00,		// 0x2C, ,
	0x00,0x08,0x08,0x08,0x08,0x08,0x00,0x00,		// 0x2D, -
	0x00,0x00,0x00,0x40,0x00,0x00,0x00,0x00,		// 0x2E, .
	0x40,0x20,0x10,0x08,0x04,0x02,0x01,0x00,		// 0x2F, /
	0x00,0x3e,0x41,0x41,0x41,0x3e,0x00,0x00,		// 0x30, 0
	0x00,0x00,0x41,0x7f,0x40,0x00,0x00,0x00,		// 0x31, 1
	0x00,0x42,0x61,0x51,0x49,0x6e,0x00,0x00,		// 0x32, 2
	0x00,0x22,0x41,0x49,0x49,0x36,0x00,0x00,		// 0x33, 3
	0x00,0x18,0x14,0x12,0x7f,0x10,0x00,0x00,		// 0x33, 4
	0x00,0x27,0x49,0x49,0x49,0x71,0x00,0x00,		// 0x35, 5
	0x00,0x3c,0x4a,0x49,0x48,0x70,0x00,0x00,		// 0x36, 6
	0x00,0x43,0x21,0x11,0x0d,0x03,0x00,0x00,		// 0x37, 7
	0x00,0x36,0x49,0x49,0x49,0x36,0x00,0x00,		// 0x38, 8
	0x00,0x06,0x09,0x49,0x29,0x1e,0x00,0x00,		// 0x39, 9
	0x00,0x00,0x00,0x12,0x00,0x00,0x00,0x00,		// 0x3A, :
	0x00,0x00,0x00,0x52,0x30,0x00,0x00,0x00,		// 0x3B, //
	0x00,0x00,0x08,0x14,0x14,0x22,0x00,0x00,		// 0x3C, <
	0x00,0x14,0x14,0x14,0x14,0x14,0x14,0x00,		// 0x3D, =
	0x00,0x00,0x22,0x14,0x14,0x08,0x00,0x00,		// 0x3E, >
	0x00,0x02,0x01,0x59,0x05,0x02,0x00,0x00,		// 0x3F, ?
	0x3e,0x41,0x5d,0x55,0x4d,0x51,0x2e,0x00,		// 0x40, @
	0x40,0x7c,0x4a,0x09,0x4a,0x7c,0x40,0x00,		// 0x41, A
	0x41,0x7f,0x49,0x49,0x49,0x49,0x36,0x00,		// 0x42, B
	0x1c,0x22,0x41,0x41,0x41,0x41,0x22,0x00,		// 0x43, C
	0x41,0x7f,0x41,0x41,0x41,0x22,0x1c,0x00,		// 0x44, D
	0x41,0x7f,0x49,0x49,0x5d,0x41,0x63,0x00,		// 0x45, E
	0x41,0x7f,0x49,0x09,0x1d,0x01,0x03,0x00,		// 0x46, F
	0x1c,0x22,0x41,0x49,0x49,0x3a,0x08,0x00,		// 0x47, G
	0x41,0x7f,0x08,0x08,0x08,0x7f,0x41,0x00,		// 0x48, H
	0x00,0x41,0x41,0x7F,0x41,0x41,0x00,0x00,		// 0x49, I
	0x30,0x40,0x41,0x41,0x3F,0x01,0x01,0x00,		// 0x4A, J
	0x41,0x7f,0x08,0x0c,0x12,0x61,0x41,0x00,		// 0x4B, K
	0x41,0x7f,0x41,0x40,0x40,0x40,0x60,0x00,		// 0x4C, L
	0x41,0x7f,0x42,0x0c,0x42,0x7f,0x41,0x00,		// 0x4D, M
	0x41,0x7f,0x42,0x0c,0x11,0x7f,0x01,0x00,		// 0x4E, N
	0x1c,0x22,0x41,0x41,0x41,0x22,0x1c,0x00,		// 0x4F, O
	0x41,0x7f,0x49,0x09,0x09,0x09,0x06,0x00,		// 0x50, P
	0x0c,0x12,0x21,0x21,0x61,0x52,0x4c,0x00,		// 0x51, Q
	0x41,0x7f,0x09,0x09,0x19,0x69,0x46,0x00,		// 0x52, R
	0x66,0x49,0x49,0x49,0x49,0x49,0x33,0x00,		// 0x53, S
	0x03,0x01,0x41,0x7f,0x41,0x01,0x03,0x00,		// 0x54, T
	0x01,0x3f,0x41,0x40,0x41,0x3f,0x01,0x00,		// 0x55, U
	0x01,0x0f,0x31,0x40,0x31,0x0f,0x01,0x00,		// 0x56, V
	0x01,0x1f,0x61,0x14,0x61,0x1f,0x01,0x00,		// 0x57, W
	0x41,0x41,0x36,0x08,0x36,0x41,0x41,0x00,		// 0x58, X
	0x01,0x03,0x44,0x78,0x44,0x03,0x01,0x00,		// 0x59, Y
	0x43,0x61,0x51,0x49,0x45,0x43,0x61,0x00,		// 0x5A, Z
	0x00,0x00,0x7f,0x41,0x41,0x00,0x00,0x00,		// 0x5B, [
	0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x00,		// 0x5C,
	0x00,0x00,0x41,0x41,0x7f,0x00,0x00,0x00,		// 0x5D, ]
	0x00,0x04,0x02,0x01,0x01,0x02,0x04,0x00,		// 0x5E, ^
	0x00,0x40,0x40,0x40,0x40,0x40,0x40,0x00,		// 0x5F, _
	0x00,0x01,0x02,0x00,0x00,0x00,0x00,0x00,		// 0x60, `
	0x00,0x34,0x4a,0x4a,0x4a,0x3c,0x40,0x00,		// 0x61, a
	0x00,0x41,0x3f,0x48,0x48,0x48,0x30,0x00,		// 0x62. b
	0x00,0x3c,0x42,0x42,0x42,0x24,0x00,0x00,		// 0x63, c
	0x00,0x30,0x48,0x48,0x49,0x3f,0x40,0x00,		// 0x63, d
	0x00,0x3c,0x4a,0x4a,0x4a,0x2c,0x00,0x00,		// 0x65, e
	0x00,0x00,0x48,0x7e,0x49,0x09,0x00,0x00,		// 0x66, f
	0x00,0x26,0x49,0x49,0x49,0x3f,0x01,0x00,		// 0x67, g
	0x41,0x7f,0x48,0x04,0x44,0x78,0x40,0x00,		// 0x68, h
	0x00,0x00,0x44,0x7d,0x40,0x00,0x00,0x00,		// 0x69, i
	0x00,0x00,0x40,0x44,0x3d,0x00,0x00,0x00,		// 0x6A, j
	0x41,0x7f,0x10,0x18,0x24,0x42,0x42,0x00,		// 0x6B, k
	0x00,0x40,0x41,0x7f,0x40,0x40,0x00,0x00,		// 0x6C, l
	0x42,0x7e,0x02,0x7c,0x02,0x7e,0x40,0x00,		// 0x6D, m
	0x42,0x7e,0x44,0x02,0x42,0x7c,0x40,0x00,		// 0x6E, n
	0x00,0x3c,0x42,0x42,0x42,0x3c,0x00,0x00,		// 0x6F, o
	0x00,0x41,0x7f,0x49,0x09,0x09,0x06,0x00,		// 0x70, p
	0x00,0x06,0x09,0x09,0x49,0x7f,0x41,0x00,		// 0x71, q
	0x00,0x42,0x7e,0x44,0x02,0x02,0x04,0x00,		// 0x72, r
	0x00,0x64,0x4a,0x4a,0x4a,0x36,0x00,0x00,		// 0x73, s
	0x00,0x04,0x3f,0x44,0x44,0x20,0x00,0x00,		// 0x73, t
	0x00,0x02,0x3e,0x40,0x40,0x22,0x7e,0x40,		// 0x75, u
	0x02,0x0e,0x32,0x40,0x32,0x0e,0x02,0x00,		// 0x76, v
	0x02,0x1e,0x62,0x18,0x62,0x1e,0x02,0x00,		// 0x77, w
	0x42,0x62,0x14,0x08,0x14,0x62,0x42,0x00,		// 0x78, x
	0x01,0x43,0x45,0x38,0x05,0x03,0x01,0x00,		// 0x79, y
	0x00,0x46,0x62,0x52,0x4a,0x46,0x62,0x00,		// 0x7A, z
	0x00,0x00,0x08,0x36,0x41,0x00,0x00,0x00,		// 0x7B, {
	0x00,0x00,0x00,0x7f,0x00,0x00,0x00,0x00,		// 0x7C, |
	0x00,0x00,0x00,0x41,0x36,0x08,0x00,0x00,		// 0x7D, }
	0x00,0x18,0x08,0x08,0x10,0x10,0x18,0x00,		// 0x7E, ~
	0xAA,0x55,0xAA,0x55,0xAA,0x55,0xAA,0x55			// 0x7F, DEL
};

/* ------------------------------------------------------------ */
/*				Local Variables									*/
/* ------------------------------------------------------------ */

BYTE rgbCmd[cbPageMax];
BYTE rgbBuf[cbPageMax];

/* ------------------------------------------------------------ */
/*				Forward Declarations							*/
/* ------------------------------------------------------------ */

void	DeviceInit();
void	AppInit();
void	AppTask();

/* ------------------------------------------------------------ */
/*				Procedure Definitions							*/
/* ------------------------------------------------------------ */
/***	main
**
**	Parameters:
**		none
**
**	Return Value:
**		not meaningful
**
**	Errors:
**		none
**
**	Description:
**		Top level main program entry point.  This main function calls
 *              on three functions:
 *              1. DeviceInit();     -- start up the hardware
 *              2. AppInit();        -- start up the software
 *              3. AppTask();        -- run the display.
*/

int
main()
	{

	DeviceInit();
	AppInit();

	while(fTrue) {
		AppTask();
	}

}

/* ------------------------------------------------------------ */
/***	DeviceInit
**
**	Parameters:
**		none
**
**	Return Value:
**		none
**
**	Errors:
**		none
**
**	Description:
**		Perform basic hardware initialization of the board.
*/

void
DeviceInit()
	{

	DelayInit();
	OledInit();
}

/* ------------------------------------------------------------ */
/***	AppInit
**
**	Parameters:
**		none
**
**	Return Value:
**		none
**
**	Errors:
**		none
**
**	Description:
**		Initialize the application.
*/

void
AppInit()
	{
	char	ch;

	OledInit();
	OledClear();

	/* Define the user definable characters
	*/
	for (ch = 0; ch < 0x18; ch++) {
		OledDefUserChar(ch, &rgbUserFont[ch*cbOledChar]);
	}

}

/* ------------------------------------------------------------ */
/***	AppTask
**
**	Parameters:
**		none
**
**	Return Value:
**		none
**
**	Errors:
**		none
**
**	Description:
**		Perform the next iteration of the embedded application
*/

void
AppTask()
	{
	int		ipag;
	int		icol;
	int		irow;
	BYTE	bVal;
	BYTE *	pb;
	int		ib;
	int		xco1;
	int		xco2;
	int		yco1;
	int		yco2;

	OledClearBuffer();

	OledSetFillPattern(OledGetStdPattern(0));
	OledSetCharUpdate(0);

	for (irow = 0; irow < crowOledMax; irow++) {
		OledClearBuffer();
		OledSetCursor(0, 0);
		OledPutString("Picard Huth");
		OledSetCursor(0, 1);
		OledPutString("Mylene Louise");
		OledSetCursor(0, 2);
		OledPutString("------------");

		OledMoveTo(0, irow);
		OledFillRect(127,31);
		OledMoveTo(0,irow);
		OledLineTo(127,irow);
		OledUpdate();
		DelayMs(100);

	}

	DelayMs(2000);

	for (irow = crowOledMax-1; irow >= 0; irow--) {
		OledSetDrawColor(1);
		OledSetDrawMode(modOledSet);
		OledMoveTo(0,irow);
		OledLineTo(127,irow);
		OledUpdate();
		DelayMs(25);
		OledSetDrawMode(modOledXor);
		OledMoveTo(0, irow);
		OledLineTo(127, irow);
		OledUpdate();
	}

	DelayMs(1000);

	OledSetDrawColor(1);
	OledSetCharUpdate(1);
	OledSetDrawMode(modOledSet);

	for (icol = 0; icol < ccolOledMax/2; icol++) {
		OledClearBuffer();
		OledMoveTo(ccolOledMax/2 - icol, 0);
		OledLineTo(ccolOledMax/2 - icol, 31);
		OledMoveTo(ccolOledMax/2 + icol, 0);
		OledLineTo(ccolOledMax/2 + icol, 31);
		OledUpdate();
		DelayMs(10);
	}

	for (icol = ccolOledMax/2; icol >= 0; icol--) {
		OledClearBuffer();
		OledMoveTo(ccolOledMax/2 - icol, 0);
		OledLineTo(ccolOledMax/2 - icol, 31);
		OledMoveTo(ccolOledMax/2 + icol, 0);
		OledLineTo(ccolOledMax/2 + icol, 31);
		OledUpdate();
		DelayMs(10);
	}

	/* Test the OledDrawPixel function.
	** This draws diagonal lines from left to right
	*/
	OledClearBuffer();
	for (icol = 0; icol < 128; icol++) {
		if (icol < 32) {
			irow = icol;
		}
		else if (icol < 64) {
			irow = 31 - (icol & 0x1F);
		}
		else if (icol < 96) {
			irow = icol & 0x1F;
		}
		else {
			irow = 31 - (icol & 0x1F);
		}
		OledMoveTo(icol, irow);
		OledDrawPixel();
	}

	OledUpdate();
	DelayMs(3000);

        /* James' test drawing function.
	** this draws a bunch of squiggle
	*/
	OledClearBuffer();
	for (icol = 0; icol < 128; icol++) {
            irow = testgraph[icol];
		OledMoveTo(icol, irow);
		OledDrawPixel();
	}

	OledUpdate();
	DelayMs(3000);

	/* Test the OledLineTo function
	*/
	OledClearBuffer();
	for (icol = 0; icol < 128; icol += 16) {
		OledMoveTo(ccolOledMax/2, crowOledMax/2);
		OledLineTo(icol, 0);
	}

	for (irow = 0; irow < 32; irow += 8) {
		OledMoveTo(ccolOledMax/2, crowOledMax/2);
		OledLineTo(127, irow);
	}

	for (icol = 0; icol < 128; icol += 16) {
		OledMoveTo(ccolOledMax/2, crowOledMax/2);
		OledLineTo(icol, 31);
	}

	for (irow = 0; irow < 32; irow += 8) {
		OledMoveTo(ccolOledMax/2, crowOledMax/2);
		OledLineTo(0, irow);
	}

	OledUpdate();
	DelayMs(3000);

	/* Test the OledFillRect function
	*/
	for (ib = 1; ib < 8; ib++) {
		OledClearBuffer();

		OledSetFillPattern(OledGetStdPattern(ib));
		OledMoveTo(5, 1);
		OledFillRect(25, 5);
		OledDrawRect(25,5);
		OledUpdate();

		OledMoveTo(30, 1);
		OledFillRect(50,10);
		OledDrawRect(50,10);
		OledUpdate();

		OledMoveTo(55, 1);
		OledFillRect(75, 27);
		OledDrawRect(75,27);
		OledUpdate();

		OledMoveTo(80, 8);
		OledFillRect(105, 23);
		OledDrawRect(105,23);
		OledUpdate();

		DelayMs(1000);
	}

	/* Test the OledDrawRect Function
	*/
	xco1 = 5;
	yco1 = 5;

	xco2 = 122;
	yco2 = 26;

	while (xco1 < xco2) {
		OledClearBuffer();

		OledMoveTo(xco1, yco1);
		OledDrawRect(xco1+15, yco1+5);

		OledMoveTo(xco2, yco1);
		OledDrawRect(xco2-15, yco1+5);

		OledMoveTo(xco1, yco2);
		OledDrawRect(xco1+15, yco2-5);

		OledMoveTo(xco2, yco2);
		OledDrawRect(xco2-15, yco2-5);

		OledUpdate();
		DelayMs(10);

		xco1 += 1;
		xco2 -= 1;
	}

	DelayMs(3000);

	/* Test the OledPutBmp function
	*/
	yco1 = 0;
	for (ib = 0; ib < 30; ib++) {
		OledClearBuffer();

		OledMoveTo(8+ib, yco1);
		OledPutBmp(8, 4, rgbBmp0);

		OledMoveTo(18+ib, yco1);
		OledPutBmp(8, 6, rgbBmp0);

		OledMoveTo(28+ib, yco1);
		OledPutBmp(8, 8, rgbBmp0);

		OledMoveTo(38+ib, yco1);
		OledPutBmp(8, 10, rgbBmp0);

		OledMoveTo(48+ib, yco1);
		OledPutBmp(8, 12, rgbBmp0);

		OledMoveTo(58+ib, yco1);
		OledPutBmp(8, 14, rgbBmp0);

		OledMoveTo(68+ib, yco1);
		OledPutBmp(8, 16, rgbBmp0);

		OledUpdate();

		if (ib <= 15) {
			yco1 += 1;
		}
		else {
			yco1 -= 1;
		}

		DelayMs(100);
	}

	/* Test moving the bitmap off the screen to the right.
	*/
	for (xco1 = ccolOledMax-16; xco1 <ccolOledMax; xco1++) {
		OledClearBuffer();
		OledMoveTo(xco1, 8);
		OledPutBmp(8, 16, rgbBmp0);
		OledUpdate();
		DelayMs(100);
	}

	/* Test moving the bitmap off the screen to the bottom.
	*/
	for (yco1 = 8; yco1 < crowOledMax; yco1++) {
		OledClearBuffer();
		OledMoveTo(40, yco1);
		OledPutBmp(8, 16, rgbBmp0);
		OledUpdate();
		DelayMs(100);
	}

	/* Test OledGetBmp
	/* This loop tests getting an 8 pixel high bitmap at each
	** possible bit offset.
	*/
	OledClearBuffer();
	for (ib = 0; ib < 8; ib++) {
		OledMoveTo(8*ib+4, ib);
		OledPutBmp(8, 8, rgbBmp0);
		OledMoveTo(8*ib+4, ib);
		OledGetBmp(8, 8, rgbBmp1);
		OledMoveTo(8*ib+4, 16+ib);
		OledPutBmp(8, 8, rgbBmp1);
		OledUpdate();
		DelayMs(100);
	}

	DelayMs(3000);

	/* This loop tests getting various sized bitmaps.
	*/
	OledClearBuffer();
	OledMoveTo(1, 3);
	OledPutBmp(8, 16, rgbBmp0);
	for (ib = 4; ib < 17; ib++) {
		OledMoveTo(1, 3);
		OledGetBmp(8, ib, rgbBmp1);
		OledMoveTo(8*ib-16, 8);
		OledPutBmp(8, ib, rgbBmp1);
		OledUpdate();
		DelayMs(100);
	}

	DelayMs(3000);

	/* Test the OledPutString function
	*/
	OledClear();

	OledSetCursor(0, 0);
	OledPutString("First Line");
	OledSetCursor(1, 1);
	OledPutString("Second Line");
	OledSetCursor(2, 2);
	OledPutString("Third Line");
	OledSetCursor(3, 3);
	OledPutString("Fourth Line");

	DelayMs(3000);

	/* Test the OledPutChar function.
	*/
	OledSetCursor(0, 0);
	for (ib = 0; ib < 64; ib ++) {
		OledPutChar('A'+ib);
		DelayMs(100);
	}

	DelayMs(3000);

	/* Test using OledPutChar to draw user defined characters
	*/
	OledClear();

	OledSetCursor(0, 0);
	OledPutString("User Defined");
	OledSetCursor(0, 1);
	OledPutString("Characters");

	OledSetCursor(0, 2);
	for (ib = 0; ib < 32; ib++) {
		OledPutChar(ib);
		DelayMs(100);
	}

	DelayMs(3000);

	/* Test drawing characters using graphics functions
	*/
	xco1 = 0;
	yco1 = 0;
	xco2 = 64;
	yco2 = 23;

	for (ib = 0; ib < 16; ib++) {
		OledClearBuffer();
		OledMoveTo(xco1+ib, yco1+ib);
		OledDrawString("ABC");
		OledMoveTo(xco2-ib, yco2-ib);
		OledDrawString("DEF");
		OledUpdate();
		DelayMs(100);
	}

	DelayMs(3000);
}




void delay(int amount)
{
    int i=0;

    while(i<(amount*100000))
    {
        i++;
    }
}


/***	DelayInit
**
**	Parameters:
**		none
**
**	Return Value:
**		none
**
**	Errors:
**		none
**
**	Description:
**		Initialized the hardware for use by delay functions. This
**		initializes Timer 1 to count at 10Mhz.
*/

void
DelayInit()
	{
	unsigned int tcfg;

	/* Configure Timer 1. This sets it up to count a 10Mhz.
	*/
	tcfg = T1_ON|T1_IDLE_CON|T1_SOURCE_INT|T1_PS_1_8|T1_GATE_OFF|T1_SYNC_EXT_OFF;
	OpenTimer1(tcfg, 0xFFFF);

}

/* ------------------------------------------------------------ */
/***	DelayMs
**
**	Parameters:
**		cms			- number of milliseconds to delay
**
**	Return Value:
**		none
**
**	Errors:
**		none
**
**	Description:
**		Delay the requested number of milliseconds. Uses Timer1.
*/

void
DelayMs(int cms)
	{
	int		ims;

	for (ims=0; ims<cms; ims++) {
		WriteTimer1(0);
		while (ReadTimer1() < cntMsDelay);
	}

}




/* ------------------------------------------------------------ */
/***	ProcName
**
**	Parameters:
**
**	Return Value:
**
**	Errors:
**
**	Description:
**
*/

/* ------------------------------------------------------------ */

/************************************************************************/

